==> haskell-yesod-auth-1.4.15-2-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-yesod-auth.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: yesod-auth
version: 1.4.15
id: yesod-auth-1.4.15-JFgHDBPDX0181SGi3hIEwj
key: yesod-auth-1.4.15-JFgHDBPDX0181SGi3hIEwj
license: MIT
maintainer: Michael Snoyman <michael@snoyman.com>
stability: Stable
homepage: http://www.yesodweb.com/
synopsis: Authentication for Yesod.
description:
    API docs and the README are available at <http://www.stackage.org/package/yesod-auth>
category: Web, Yesod
author: Michael Snoyman, Patrick Brisbin
exposed: True
exposed-modules:
    Yesod.Auth Yesod.Auth.BrowserId Yesod.Auth.Dummy Yesod.Auth.Email
    Yesod.Auth.OpenId Yesod.Auth.Rpxnow Yesod.Auth.Message
    Yesod.Auth.GoogleEmail Yesod.Auth.GoogleEmail2 Yesod.Auth.Hardcoded
hidden-modules: Yesod.Auth.Routes Yesod.PasswordStore
abi: 1f42b2e450622409b6a0f78165802f7e
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/yesod-auth-1.4.15
library-dirs: /usr/lib/ghc-8.0.1/site-local/yesod-auth-1.4.15
data-dir: /usr/share/arm-linux-ghc-8.0.1/yesod-auth-1.4.15
hs-libraries: HSyesod-auth-1.4.15-JFgHDBPDX0181SGi3hIEwj
depends:
    aeson-0.11.2.0-31ZI7bFuFz27ynqHifCKlM
    authenticate-1.3.3.2-93gNT0g0V2YBf3ZnBHCBpZ base-4.9.0.0
    base16-bytestring-0.1.1.6-5dPoF8dzhwzBaEB2MvnmIS
    base64-bytestring-1.0.0.1-In9M41tLtcS9QYt3QpGpNY binary-0.8.3.0
    blaze-builder-0.4.0.2-2VmGHau0mFrAjwd4n28WWF
    blaze-html-0.8.1.3-J9yr8vH3H9ALelvCpTjDjF
    blaze-markup-0.7.1.1-JmLydCOPoKfKgaFgoOctdP
    byteable-0.1.1-15aIBCArSOBEnGxArzrDTM bytestring-0.10.8.1
    conduit-1.2.8-7nV18MBUUw27H5V6KPeFTb
    conduit-extra-1.1.15-10q3cKRpmQz8slt9iWhPKJ containers-0.5.7.1
    cryptohash-0.11.9-CHhBSmBCUcKEKkvIohRX6n
    data-default-0.7.1.1-ZpKfkXGfJa8c8Q6OFbvrr
    email-validate-2.2.0-BX7OHmdaIiKJrWrWOnmGfg
    file-embed-0.0.10-IXfudWSq57y1Athysk5ifZ
    http-client-0.5.4-HBBQ11vQccaG7MFhX9DRCl
    http-conduit-2.2.3-ILM426eTCjq3iUuxocDIbm
    http-types-0.9.1-58mzFhAgNAb9DH0XYXjd5P
    lifted-base-0.2.3.8-49pRtI70Gt75UpVUvp7oxA
    mime-mail-0.4.12-27YnCtJjD7DIgVIHjJxwAM
    network-uri-2.6.1.0-8yR4gjnzE4eDGhJR7PHfVJ
    nonce-1.0.2-7sb9xV9gLCWCWWtYux6nAR
    persistent-2.6-77DikruvbVL9pOFeHHOR24
    persistent-template-2.5.1.6-KSFXNgpY2DOBs4VE2Xvgj9
    random-1.1-54KmMHXjttlERYcr1mvsAe
    resourcet-1.1.8.1-Fz8VsTwAt9A4JeouKpXV1P
    safe-0.3.10-1VyrsjWhmjvGnGud5lgW7f
    shakespeare-2.0.11.2-GC7KY8bLbGk7xXYbUzyJx6
    template-haskell-2.11.0.0 text-1.2.2.1-FgcR4Xf0VlEHD9HLxzq9WJ
    time-1.6.0.1 transformers-0.5.2.0
    unordered-containers-0.2.7.1-6Q3w38ZivLTB9nLFgf8RUI
    wai-3.2.1.1-3kBgN7EuSbyJsj8pT2dpLl
    yesod-core-1.4.30-8Yp8hhmqmu58smgiwMgQ4w
    yesod-form-1.4.9-Iycab4ByZxWKaTExGCJTro
    yesod-persistent-1.4.1.0-3ydDl7MpZ77O85GDjY2Dy
haddock-interfaces: /usr/share/doc/haskell-yesod-auth/html/yesod-auth.haddock
haddock-html: /usr/share/doc/haskell-yesod-auth/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-yesod-auth-1.4.15-13-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-yesod-auth.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: yesod-auth
version: 1.4.15
id: yesod-auth-1.4.15-AeCUy3iTY8BCa7qASEYyJL
key: yesod-auth-1.4.15-AeCUy3iTY8BCa7qASEYyJL
license: MIT
maintainer: Michael Snoyman <michael@snoyman.com>
stability: Stable
homepage: http://www.yesodweb.com/
synopsis: Authentication for Yesod.
description:
    API docs and the README are available at <http://www.stackage.org/package/yesod-auth>
category: Web, Yesod
author: Michael Snoyman, Patrick Brisbin
exposed: True
exposed-modules:
    Yesod.Auth Yesod.Auth.BrowserId Yesod.Auth.Dummy Yesod.Auth.Email
    Yesod.Auth.OpenId Yesod.Auth.Rpxnow Yesod.Auth.Message
    Yesod.Auth.GoogleEmail Yesod.Auth.GoogleEmail2 Yesod.Auth.Hardcoded
hidden-modules: Yesod.Auth.Routes Yesod.PasswordStore
abi: 998d99308f1af6accfde1094c18506eb
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/yesod-auth-1.4.15
library-dirs: /usr/lib/ghc-8.0.1/site-local/yesod-auth-1.4.15
data-dir: /usr/share/arm-linux-ghc-8.0.1/yesod-auth-1.4.15
hs-libraries: HSyesod-auth-1.4.15-AeCUy3iTY8BCa7qASEYyJL
depends:
    aeson-1.0.2.1-48fgDxXkzxa6ZDVUGzjqxN
    authenticate-1.3.3.2-LFJ7AhbQ6oK5acJtkOkn7X base-4.9.0.0
    base16-bytestring-0.1.1.6-5dPoF8dzhwzBaEB2MvnmIS
    base64-bytestring-1.0.0.1-In9M41tLtcS9QYt3QpGpNY binary-0.8.3.0
    blaze-builder-0.4.0.2-2VmGHau0mFrAjwd4n28WWF
    blaze-html-0.8.1.3-J9yr8vH3H9ALelvCpTjDjF
    blaze-markup-0.7.1.1-JmLydCOPoKfKgaFgoOctdP
    byteable-0.1.1-15aIBCArSOBEnGxArzrDTM bytestring-0.10.8.1
    conduit-1.2.8-D9dRTYSavk8HJ0UStkfE43
    conduit-extra-1.1.15-FSdOtryxOIZL6vIsq9443u containers-0.5.7.1
    cryptohash-0.11.9-DHI6HEU0ngdHLXXk1TIe9A
    data-default-0.7.1.1-ZpKfkXGfJa8c8Q6OFbvrr
    email-validate-2.2.0-GSSjipzx4RxJDHwv5DVwLn
    file-embed-0.0.10-IXfudWSq57y1Athysk5ifZ
    http-client-0.5.5-IwHpSkqRbxJJXgW2dGYNud
    http-conduit-2.2.3-2fVGs6GBNGNLn8jAlaUBrX
    http-types-0.9.1-86VKlfjfTunGvWNFdOLeV5
    lifted-base-0.2.3.8-49pRtI70Gt75UpVUvp7oxA
    mime-mail-0.4.12-27YnCtJjD7DIgVIHjJxwAM
    network-uri-2.6.1.0-8yR4gjnzE4eDGhJR7PHfVJ
    nonce-1.0.2-1EkL7fu4kw4EKAkfUDmryE
    persistent-2.6-8jLMJikErgcAzz2jOlY2Ud
    persistent-template-2.5.1.6-Dv5YKxcG9V36q0KJAcfH7U
    random-1.1-54KmMHXjttlERYcr1mvsAe
    resourcet-1.1.9-J17FkGhZ2yV57Ehh8hruPC
    safe-0.3.10-1VyrsjWhmjvGnGud5lgW7f
    shakespeare-2.0.12.1-2U1eaPz77p24ZIm74O13e8
    template-haskell-2.11.0.0 text-1.2.2.1-FgcR4Xf0VlEHD9HLxzq9WJ
    time-1.6.0.1 transformers-0.5.2.0
    unordered-containers-0.2.7.2-2cqAiy5FQsv48ljFn9vXL1
    wai-3.2.1.1-9mMHgVB1wYz4uCkr33AuWK
    yesod-core-1.4.30-DcjksReL9st6dibXdmXEQV
    yesod-form-1.4.9-GNglRiKqYjU7LX9hjCLUOm
    yesod-persistent-1.4.1.1-LqSgPwItGoakCo4ZPphsg
haddock-interfaces: /usr/share/doc/haskell-yesod-auth/html/yesod-auth.haddock
haddock-html: /usr/share/doc/haskell-yesod-auth/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
